﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
using ElementAccount = SolidFire.Element.Api.Account;

#endregion

namespace SolidFire.Account.Remove
{
    /// <summary>
    /// RemoveSFAccount is used to remove an existing account. All Volumes must be deleted and purged on the account before it can be
    /// removed. If volumes on the account are still pending deletion, RemoveAccount cannot be used. DeleteVolume to delete and purge
    /// the volumes.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFAccount", SupportsShouldProcess = true, DefaultParameterSetName = "AccountId", ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFAccount : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// 
        /// </summary>
        private Int64[] _accountId;
        private ElementAccount[] _account;
        #endregion

        #region Parameters

        /// <summary>
        /// 
        /// </summary>
        [Parameter(Position = 0, ParameterSetName = "AccountId", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter an account ID")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] AccountID
        {
            get
            {
                return _accountId;
            }
            set
            {
                _accountId = value;
            }
        }

        /// <summary>
        /// 
        /// </summary>
        [Parameter(Position = 0, ParameterSetName = "SFAccountIn", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter an account ID")]
        [ValidateNotNullOrEmpty]
        public ElementAccount[] Account
        {
            get
            {
                return _account;
            }
            set
            {
                _account = value;
            }
        }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            switch (ParameterSetName)
            {
                case "AccountId":

                    foreach (var accId in _accountId)
                    {
                        var request = new RemoveAccountRequest();
                        request.AccountID = accId;
                        SendRequest<RemoveAccountResult>("RemoveAccount", request);
                    }
                    break;

                case "SFAccountIn":

                    foreach (var acc in _account)
                    {
                        var request = new RemoveAccountRequest();
                        request.AccountID = acc.AccountID;
                        SendRequest<RemoveAccountResult>("RemoveAccount", request);
                    }

                    break;

                default:
                    throw new ArgumentException("Invalid parameter set.");
            }
        }

        #endregion
    }
}