﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Cluster.Get
{
    /// <summary>
    /// ListVirtualNetworks is used to get a list of all the configured virtual networks for the cluster. This method can be used to verify
    /// the virtual network settings in the cluster.
    /// This method does not require any parameters to be passed. But, one or more VirtualNetworkIDs or VirtualNetworkTags can be
    /// passed in order to filter the results.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFVirtualNetwork", DefaultParameterSetName="None")]
    public class GetSFVirtualNetwork : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters
        /// <summary>
        /// Network IDs to return in the list.
        /// </summary>
        [Parameter(Position = 0,
            ParameterSetName = "VirtualNetworkID",
            Mandatory = false,
            ValueFromPipeline = true,
            ValueFromPipelineByPropertyName = true,
            ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a VirtualNetworkID or list of VirtualNetworkIDs")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] VirtualNetworkID { get; set; }

        /// <summary>
        /// Network Tags to include in the list.
        /// </summary>
        [Parameter(Position = 0,
            ParameterSetName = "VirtualNetworkTag",
            Mandatory = false,
            ValueFromPipeline = true,
            ValueFromPipelineByPropertyName = true,
            ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a VirtualNetworkTag or list of VirtualNetworkTag")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] VirtualNetworkTag { get; set; }
        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection(minVersionNumber: 7.0f);
        }
        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var request = new ListVirtualNetworksRequest();

            switch (ParameterSetName)
            {
                case "VirtualNetworkID":
                    request.VirtualNetworkIDs = VirtualNetworkID;
                    break;
                case "VirtualNetworkTag":
                    request.VirtualNetworkTags = VirtualNetworkTag;
                    break;
            }

            var objsFromAPI = SendRequest<ListVirtualNetworksResult>("ListVirtualNetworks", request);

            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result.VirtualNetworks, true);
            }
        }


        #endregion
    }
}
