﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Cluster.Remove
{
    /// <summary>
    /// ClearClusterFaults is used to clear information about both current faults that are resolved as well as faults that were previously
    /// detected and resolved can be cleared.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFClusterFault", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFClusterFault : SFCmdlet
    {
        #region Private Data

        private string _faultType = "all";

        #endregion

        #region Parameters

        [Parameter(Position = 0, Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = true, HelpMessage = "Specify the fault type to be removed.")]
        [ValidateSet("all", "current", "resolved", IgnoreCase = true)]
        public string FaultType {
            get { return _faultType; }
            set { _faultType = value.ToLower(); } 
        }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var request = new ClearClusterFaultsRequest();
            request.FaultTypes = _faultType;

            var objsFromAPI = SendRequest<ClearClusterFaultsResult>("ClearClusterFaults", request);

            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result);
            }

        }
        #endregion
    }
}
