﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;

#endregion

namespace SolidFire.Cluster.Remove
{
    /// <summary>
    /// Used to disconnect the open connections between two clusters created by cluster pairing.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFClusterPair", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFClusterPair : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters

        /// <summary>
        /// A string of characters that is returned from the StartClusterPairing API method.
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "Unique identifier used to pair two clusters.")]
        public long ClusterPairID { get; set; }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var request = new RemoveClusterPairRequest();
            request.ClusterPairID = ClusterPairID;

            var objsFromAPI = SendRequest<RemoveClusterPairResult>("RemoveClusterPair", request);

            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result);
            }
        }

        #endregion
    }
}