﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using System.Management.Automation.Runspaces;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Cluster.Remove
{
    /// <summary>
    /// RemoveVirtualNetwork is used to remove a previously added virtual network.
    /// NOTE: This method requires either the VirtualNetworkID or the VirtualNetworkTag as a parameter, but not both.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFVirtualNetwork", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFVirtualNetwork : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// Member used to host a nested Pipeline for calling other CmdLets
        /// </summary>
        private Pipeline pipeline = null;

        #endregion

        #region Parameters

        /// <summary>
        /// Network ID to remove.
        /// </summary>
        [Parameter(Position = 0,
            ParameterSetName = "VirtualNetworkID",
            Mandatory = true,
            ValueFromPipeline = true,
            ValueFromPipelineByPropertyName = true,
            ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a VirtualNetworkID to remove.")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 VirtualNetworkID { get; set; }


        /// <summary>
        /// Network Tag to remove.
        /// </summary>
        [Parameter(Position = 0,
            ParameterSetName = "VirtualNetworkTag",
            Mandatory = true,
            ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a VirtualNetworkTag to remove.")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 VirtualNetworkTag { get; set; }


        #endregion

        #region Cmdlet Overrides

        /// <summary>
        /// Create a nested pipeline that can be written to after processing
        /// </summary>
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            pipeline = Runspace.DefaultRunspace.CreateNestedPipeline();
            CheckConnection(minVersionNumber: 7.0f);
        }

        /// <summary>
        /// After processing, invoke Get-SFClusterAdmin so the latest list of admins is passed into the pipeline
        /// </summary>
        protected override void EndProcessing()
        {
            base.EndProcessing();
            var command = new Command("Get-SFVirtualNetwork");
            pipeline.Commands.Add(command);
            
            // Send it to the pipline
            WriteObject(pipeline.Invoke(), true);
            pipeline = null;
        }

        /// <summary>
        /// Implementation for processing the execution of the cmdlet.
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var request = new RemoveVirtualNetworkRequest();

            switch (ParameterSetName)
            {
                case "VirtualNetworkID":
                    request.VirtualNetworkID = VirtualNetworkID;
                    break;
                case "VirtualNetworkTag":
                    request.VirtualNetworkTag = VirtualNetworkTag;
                    break;
            }

            SendRequest<RemoveVirtualNetworkResult>("RemoveVirtualNetwork", request);

        }

        #endregion
    }
}