﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Cluster.Test
{
    /// <summary>
    /// The TestLdapAuthentication is used to verify the currently enabled LDAP authentication configuration settings are correct. If
    /// the configuration settings are correct, the API call returns a list of the groups the tested user is a member of.
    /// </summary>
    
    [Cmdlet(VerbsDiagnostic.Test, "SFLdapAuthentication")]
    public class TestSFLdapAuthentication : SFCmdlet
    {
        #region Private Data
        
        #endregion

        #region Parameters

        /// <summary>
        /// The distinguished user name for the new LDAP cluster admin.
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, HelpMessage = "The distinguished user name for the new LDAP cluster admin.")]
        public String Username { get; set; }

        /// <summary>
        /// The password of the username to be tested.
        /// </summary>
        [Parameter(Position = 1, Mandatory = true, ValueFromPipeline = true, HelpMessage = "The password for the username to be tested.")]
        public String Password { get; set; }

        /// <summary>
        /// An LdapConfiguration object to be tested. If this parameter is provided, 
        /// the API call will test the provided configuration even if LDAP authentication is currently disabled.
        /// </summary>
        [Parameter(Position = 2, Mandatory = false, ValueFromPipeline = false, HelpMessage = "An LdapConfiguration object to be tested. Optional.")]
        public LdapConfiguration LdapConfiguration { get; set; }

        #endregion

        #region Cmdlet Overrides

        /// <summary>
        /// Create a nested pipeline that can be written to after processing
        /// </summary>
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection(minVersionNumber: 8.0f);
        }

        /// <summary>
        /// Implementation for processing the execution of the cmdlet.
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            // Assemble the parameters object
            var request = new TestLdapAuthenticationRequest();
            request.Username = Username;
            request.Password = Password;
            request.LdapConfiguration = LdapConfiguration;

           var objsFromAPI = SendRequest<TestLdapAuthenticationResult>("TestLdapAuthentication", request);
           foreach (var obj in objsFromAPI)
           {
               WriteObject(obj.Result);
           }

        }

        #endregion
    }
}