﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion


#region Using Directives
using SolidFire.Exceptions;
using System;
using System.Text.RegularExpressions;
#endregion

namespace SolidFire.Core.Validation
{
    /// <summary>
    /// 
    /// </summary>
    public static class SolidFireValidations
    {

        /// <summary>
        /// 
        /// </summary>
        public const String GreaterThanZero = @"^[-+]?[1-9]\d*\.?[0]*$";

        /// <summary>
        /// 
        /// </summary>
        public const String SizeMin = @"\b([1-9][0-9]{2,3}|1[0-4][0-9]{3}|15000)\b";

        /// <summary>
        /// 
        /// </summary>
        public const String SizeMax = @"1[5-9][0-9]{3}|[2-9][0-9]{4}|100000";

        /// <summary>
        /// 
        /// </summary>
        public const String Numeric = @"[0-9\.]+";

        /// <summary>
        /// 
        /// </summary>
        public const String UpperCase = @"[A-Z]+";

        /// <summary>
        /// 
        /// </summary>
        public const String LowerCase = @"[a-z]+";

        /// <summary>
        /// 
        /// </summary>
        public const String UpperAndLowerCase = @"[A-Za-z]+";

        /// <summary>
        /// 
        /// </summary>
        public const String UpperAndLowerCaseAndNumeric = @"[A-Za-z0-9]+";

        /// <summary>
        /// 
        /// </summary>
        public const String UpperAndLowerCaseNumericAndDots = @"[A-Za-z0-9\.]+";

        /// <summary>
        /// A regex expression to validate a string as a ISO-8601 date 
        /// </summary>
        public const String ISO8601DateTimeOrEmptyString = @"^$|^([\+-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24\:?00)([\.,]\d+(?!:))?)?(\17[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$";
        
        /// <summary>
        /// A regex expression to validate HHHHHHH:mm:ss. Validates up to 1999999:59:59
        /// </summary>
        public const String HoursMinutesSeconds = @"^(?:(?:([1]?[0-9]?[0-9]?[0-9]?[0-9]?[0-9]?[0-9]?\d):)?([0-5]?\d):)?([0-5]?\d)$";

        /// <summary>
        /// Checks a string value being submitted as retention time against business logic. Retention time cannot be greater than 10,000,000:00:00. Will throw ParameterException if a problem occurs.
        /// </summary>
        /// <param name="value">value to test for retention</param>
        public static void ValidateHoursMinutesSecondsForRetention(string value)
        {
            var match = Regex.Match(value, HoursMinutesSeconds);
            if (match.Groups[1].Success &&
                ((int.Parse(match.Groups[1].Value) > 10000000) ||
                (int.Parse(match.Groups[1].Value) == 10000000 &&
                int.Parse(match.Groups[2].Value) != 0 &&
                int.Parse(match.Groups[3].Value) != 0)))
            {
                throw new ParameterException("Retention Hours can not be greater than 10,000,000:00:00.");
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public const String IPAddress = @"(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)";

        /// <summary>
        /// A regex validation to ensure the item conforms to the standard iSCSI initiator format
        /// </summary>
        // Validation Pattern is too restrictive
#if ALLOW_ISCSI_NAME_VALIDATION
        public const string iSCSIInitiator = @"^(?:iqn\.[0-9]{4}-[0-9]{1,2}(?:\.[A-Za-z](?:[A-Za-z0-9\-]*[A-Za-z0-9])?)+(?::.*)?|eui\.[0-9A-Fa-f]{16})\z";
#endif
    }
}