﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Management.Automation;
using SolidFire.Core.Helpers;
using SolidFire.Core.Objects;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;

#endregion

namespace SolidFire.Drive.Get
{
    /// <summary>
    /// Used to return the list of the drives that exist in the cluster's active nodes. Drives that have been added as volume
    /// metadata or block drives, as well as drives that have not been added and are available are returned.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFDrive")]
    public class GetSFDrive : SFCmdlet
    {
        #region Parameters

        [Parameter(Position = 0, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "Please enter a drive ID or list of drive IDs")]
        public Int64[] DriveID { get; set; }

        [Parameter(Position = 0, Mandatory = false, HelpMessage = "Filter the returned drives by one or more Status values.")]
        [ValidateSet("active", "available", "erasing", "failed", "removing")]
        public String[] Status { get; set; }

        #endregion

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }
        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var objsFromAPI = SendRequest<ListDrivesResult>("ListDrives");

            var drives = new List<DriveInfo>();

            foreach (var obj in objsFromAPI)
            {
                drives.AddRange(FilterByStatus(FilterByDriveID(obj.Result.Drives.ToList()).ToList()));
            }
            WriteObject(drives, true);
        }

        private IEnumerable<DriveInfo> FilterByStatus(List<DriveInfo> drivesToFilter)
        {
            return Status == null ? drivesToFilter : drivesToFilter.Where(d => Status.Select(x => x.ToLower()).Contains(d.Status));
        }

        private IEnumerable<DriveInfo> FilterByDriveID(List<DriveInfo> drivesToFilter)
        {
            return DriveID == null ? drivesToFilter : drivesToFilter.Where(d => DriveID.ToList().Contains(d.DriveID));
        }
    }
}