﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Drive.Get
{
    /// <summary>
    /// Rreturns all the hardware info for the given drive. This generally includes manufacturers, vendors, versions, and
    /// other associated hardware identification information.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFDriveHardwareInfo", DefaultParameterSetName = "DriveID")]
    public class GetSFDriveHardwareInfo : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "DriveID", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a drive ID, or list of Drive IDs.")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] DriveID { get; set; }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }
        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            foreach (var drive in DriveID)
            {
                var request = new GetDriveHardwareInfoRequest();
                request.DriveID = drive;
                var objsFromAPI = SendRequest<GetDriveHardwareInfoResult>("GetDriveHardwareInfo", request);
                foreach (var obj in objsFromAPI)
                {
                    WriteObject(obj.Result.DriveHardwareInfo, true);
                }
            }
        }

        #endregion
    }
}
