﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.Linq;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Helpers;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Drive.Get
{
    /// <summary>
    /// Return high-level activity measurements for a single drive. Values are cumulative from the addition of the drive to the
    /// cluster. Some values are specific to Block Drives. Statistical data may not be returned for both block and metadata drives when
    /// running this method.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFDriveStats", DefaultParameterSetName = "DriveIDs")]
    public class GetSFDriveStats : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// 
        /// </summary>
        Int64? _driveID;

        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "DriveID", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a drive ID")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 DriveID
        {
            get
            {
                return _driveID.GetValueOrDefault(0);
            }
            set
            {
                _driveID = value;
            }
        }
        #endregion

        [Parameter(Position = 0, ParameterSetName = "DriveIDs", Mandatory = false, HelpMessage = "Please enter a drive ID or list of drive IDs")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] DriveIDs { get; set; }

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            if(ParameterSetName == "DriveIDs")
            {
                CheckConnection(9);
            }
            else
            {
                CheckConnection();
            }
        }
        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            if(ParameterSetName == "DriveIDs")
            {
                var request = new ListDriveStatsRequest();
                request.Drives = DriveIDs;
                var objsFromAPI = SendRequest<ListDriveStatsResult>("ListDriveStats", request);
                WriteObject(objsFromAPI.Select(obj => obj.Result.DriveStats), true);
            }
            else
            {
                var request = new GetDriveStatsRequest();
                request.DriveID = DriveID;
                var objsFromAPI = SendRequest<GetDriveStatsResult>("GetDriveStats", request);
                WriteObject(objsFromAPI.Select(obj => obj.Result.DriveStats), true);
            }
        }

        #endregion
    }
}