#region Copyright
/*
* Copyright 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion


#region Using Directives
using System;
using System.Linq;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Hardware
{
	/// <summary>
	/// You can use the GetClusterHardwareInfo method to retrieve the hardware status and information for all Fibre Channel nodes, iSCSI nodes and drives in the cluster. This generally includes manufacturers, vendors, versions, and other associated hardware identification information.
	/// </summary>
	
	[Cmdlet(VerbsCommon.Get, "SFClusterHardwareInfo")]
	public class GetClusterHardwareInfo : SFCmdlet
	{
		#region Private Data
		/// <summary>
		/// Include only a certain type of hardware information in the response. Can be one of the following:drives: List only drive information in the response.nodes: List only node information in the response.all: Include both drive and node information in the response.If this parameter is omitted, a type of "all" is assumed.
		/// </summary>
		private string _type = "all";
		#endregion
		
		#region Parameters
		[Parameter(Mandatory = false, HelpMessage = "Include only a certain type of hardware information in the response. Can be either \"drives\", \"nodes\", or \"all\". If this parameter is omitted, a type of \"all\" is assumed.")]
		[ValidateSet("drives", "nodes", "all")]
		public string Type
		{
			get
			{
				return _type;
			}
			set
			{
				_type = value;
			}
		}
		#endregion
		
		#region Cmdlet Overrides
		protected override void BeginProcessing()
		{
			base.BeginProcessing();
			CheckConnection();
		}

		protected override void ProcessRecord()
		{
			base.ProcessRecord();
			var request = new GetClusterHardwareInfoRequest();
			request.Type = _type;
			var objsFromAPI = SendRequest<GetClusterHardwareInfoResult>("GetClusterHardwareInfo", request);
			WriteObject(objsFromAPI.Select(obj => obj.Result.ClusterHardwareInfo), true);
		}
		#endregion
	}
}
		