﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives
using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Node.Add
{
    /// <summary>
    /// Used to add one or more new nodes to the cluster. When a node is not configured and starts up for the first time you
    /// are prompted to configure the node. Once a node is configured it is registered as a "pending node" with the cluster.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Add, "SFNode", ConfirmImpact = ConfirmImpact.Medium)]
    public class AddSFNode : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters

        /// <summary>
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true,
            ValueFromRemainingArguments = true, HelpMessage = "Please enter one or more pending Node IDs")]
        [ValidateNotNullOrEmpty]
        public Int64[] PendingNodeID { get; set; }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }
        ///// <summary>
        ///// 
        ///// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var request = new AddNodesRequest();
            request.PendingNodes = PendingNodeID;
            var objsFromAPI = SendRequest<AddNodesResult>("AddNodes", request);

            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result.Nodes, true);
            }
        }

        #endregion
    }
}