﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Management.Automation;
using SolidFire.Core.Helpers;
using SolidFire.Core.Objects;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
using ElementNode = SolidFire.Element.Api.Node;
#endregion

namespace SolidFire.Node.Get
{
    /// <summary>
    /// Used to return a list of active nodes in the cluster.
    /// </summary>

    [Cmdlet(VerbsCommon.Get, "SFActiveNode", DefaultParameterSetName = "NodeId")]
    public class GetSFNode : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// 
        /// </summary>
        private Int64[] nodeId;

        private string[] name;

        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "NodeId", Mandatory = false, ValueFromPipeline = true,
            ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a node ID or list of node IDs")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] NodeID
        {
            get { return nodeId; }
            set { nodeId = value; }
        }

        [Parameter(Position = 0, ParameterSetName = "Name", Mandatory = false, ValueFromPipeline = true,
            ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false,
            HelpMessage = "Please enter a node name or list of node names")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.UpperAndLowerCase)]
        public String[] Name
        {
            get { return name; }
            set { name = value; }
        }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var objsFromAPI = SendRequest<ListActiveNodesResult>("ListActiveNodes");

            foreach (var obj in objsFromAPI)
            {
                switch (ParameterSetName)
                {
                    case "NodeId":
                        ProcessByNodeId(obj);
                        break;

                    case "Name":
                        ProcessByName(obj);
                        break;

                    default:
                        throw new ArgumentException("Invalid parameter set.");
                }
            }
        }

        private void ProcessByName(SFWrapper<ListActiveNodesResult> objFromApi)
        {
            const WildcardOptions options = WildcardOptions.IgnoreCase |
                                            WildcardOptions.Compiled;

            var nodeInfoObjects = new List<ElementNode>();

            foreach (var nodeName in name)
            {
                var wildcard = new WildcardPattern(nodeName, options);
                var foundNodes = objFromApi.Result.Nodes.Where(r => (wildcard.IsMatch(r.Name))).ToList<ElementNode>();
                nodeInfoObjects.AddRange(foundNodes);
            }

            if (nodeInfoObjects.Count > 0)
            {
                WriteObject(nodeInfoObjects.Distinct(), true);
            }
        }

        private void ProcessByNodeId(SFWrapper<ListActiveNodesResult> objFromApi)
        {
            // If there were no parameter arguments sent in for the nodeID parameter then we just want to list all nodes and their information.
            if (nodeId == null)
            {
                WriteObject(objFromApi.Result.Nodes, true);
                return;
            }

            foreach (var id in nodeId)
            {
                var nodeInfoObject = objFromApi.Result.Nodes.FirstOrDefault(r => r.NodeID == id);
                WriteObject(nodeInfoObject);

            }
        }

        #endregion
    }
}