﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Node.Get
{
    /// <summary>
    /// GetNodeStats is used to return the high-level activity measurements for a lide of nodes or all nodes.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFNodeStats")]
    public class GetSFNodeStats : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// 
        /// </summary>
        private Int64[] _nodeID;

        #endregion

        #region Parameters
        
        [Parameter(Position = 0, Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a node ID or list of node IDs")]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] NodeID
        {
            get
            {
                return _nodeID;
            }
            set
            {
                _nodeID = value;
            }
        }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            if (_nodeID != null)
            {
                foreach (var id in _nodeID){
                    var request = new GetNodeStatsRequest();
                    request.NodeID = id;
                    var results = SendRequest<GetNodeStatsResult>("GetNodeStats", request);
                    foreach (var obj in results)
                    {
                        obj.Result.NodeStats.NodeID = id;
                        WriteObject(obj.Result.NodeStats);
                    }
                }
            }
            else
            {
                var results = SendRequest<ListNodeStatsResult>("ListNodeStats");
                foreach (var obj in results)
                {
                    WriteObject(obj.Result.NodeStats.Nodes, true);
                }
            }
        }

        #endregion
    }
}
