﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Objects;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Node.Get
{
    /// <summary>
    /// Used to return a list of pending nodes in the cluster.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Get, "SFPendingNode", DefaultParameterSetName = "PendingNodeId")]
    public class GetSFPendingNode : SFCmdlet
    {
        #region Private Data

        /// <summary>
        /// 
        /// </summary>
        private Int64[] _pendingNodeId;

        private string[] name;

        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "PendingNodeId", Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a pending node ID or list of pending node IDs")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] PendingNodeID
        {
            get
            {
                return _pendingNodeId;
            }
            set
            {
                _pendingNodeId = value;
            }
        }

        [Parameter(Position = 0, ParameterSetName = "Name", Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a pending node name or list of pending node names")]
        [ValidateNotNullOrEmpty]
        public String[] Name
        {
            get
            {
                return name;
            }
            set
            {
                name = value;
            }
        }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }
        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var objsFromAPI = SendRequest<ListPendingNodesResult>("ListPendingNodes");

            foreach (var obj in objsFromAPI)
            {
                switch (ParameterSetName)
                {
                    case "PendingNodeId":
                        ProcessByNodeId(obj);
                        break;

                    case "Name":
                        ProcessByName(obj);
                        break;

                    default:
                        throw new ArgumentException("Invalid parameter set.");
                }
            }
        }

        private void ProcessByName(SFWrapper<ListPendingNodesResult> objFromApi)
        {
            const WildcardOptions options = WildcardOptions.IgnoreCase |
                                            WildcardOptions.Compiled;

            foreach (var nameParam in name)
            {
                var matchedNodes = new List<PendingNode>();
                foreach (var sfPendingNodeDetails in objFromApi.Result.PendingNodes)
                {
                    var wildcard = new WildcardPattern(nameParam, options);
                    if (wildcard.IsMatch(sfPendingNodeDetails.Name))
                    {
                        if (!matchedNodes.Contains(sfPendingNodeDetails))
                        {
                            matchedNodes.Add(sfPendingNodeDetails);
                        }
                    }
                }

                if (matchedNodes.Count > 0)
                {
                    WriteObject(matchedNodes, true);
                }
                
            }
        }

        private void ProcessByNodeId(SFWrapper<ListPendingNodesResult> objFromApi)
        {
            // If there were no parameter arguments sent in for the pending node ID parameter then we just want to list all pending nodes and their information.
            if (_pendingNodeId == null)
            {
                WriteObject(objFromApi.Result.PendingNodes, true);
                return;
            }

            foreach (var id in _pendingNodeId)
            {
                foreach (var sfPendingNodeDetails in objFromApi.Result.PendingNodes)
                {
                    if (sfPendingNodeDetails.PendingNodeID != id) continue;
                    WriteObject(sfPendingNodeDetails);
                    break;
                }
            }
        }

        #endregion
    }
}