﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Helpers;
using SolidFire.Core;
using SolidFire.Element.Api;
using SolidFire.Core.Objects;
#endregion

namespace SolidFire.Node.New
{
    /// <summary>
    /// New-SFNodeSupportBundle is used to gather support bundles from all the nodes in a cluster. When the bundle has been successfully created, the bundle is stored on the node as a tar.gz file.
    /// </summary>
    
    [Cmdlet(VerbsCommon.New, "SFNodeSupportBundle")]
    public class NewSFNodeSupportBundle : SFCmdlet
    {
        #region Private Data

        private int _timeoutSec = 1500;
        private const int HTTP_TIMEOUT_BUFFER_SECS = 5;

        #endregion

        #region Parameters

        /// <summary>
        /// Unique name for each support bundle created. If no name is provided, then 'supportbundle' and the node name is used as a file name.
        /// </summary>
        [Parameter(Position = 0, Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "Unique name for each support bundle created. If no name is provided, then 'supportbundle' and the node name is used as a file name.")]
        public String BundleName { get; set; }

        /// <summary>
        /// This parameter is fed to the sf_make_support_bundle script. Should be used only at the request of SolidFire Support.
        /// </summary>
        [Parameter(Position = 1, Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "This parameter is fed to the sf_make_support_bundle script. Should be used only at the request of SolidFire Support.")]
        public String ExtraArgs { get; set; }

        /// <summary>
        /// This parameter overrides the Timeout parameter in the SFConnection object. It is fed to the sf_make_support_bundle script. Should be used only at the request of SolidFire Support. 
        /// </summary>
        [Parameter(Position = 2, Mandatory = false, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "This parameter overrides the Timeout parameter in the SFConnection object. It is fed to the sf_make_support_bundle script. Should be used only at the request of SolidFire Support.")]
        public int TimeoutSec { set { _timeoutSec = value; } }

        #endregion

        #region Cmdlet Overrides

        /// <summary>
        /// Create a nested pipeline that can be written to after processing
        /// </summary>
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection(minVersionNumber: 8.0f, endPoint: SolidFireUtilities.SFEndPoint.Node);
        }

        /// <summary>
        /// Implementation for processing the execution of the cmdlet.
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            // Assemble the parameters object
            var request = new CreateSupportBundleRequest();
            request.BundleName = BundleName;
            request.ExtraArgs = ExtraArgs;
            request.TimeoutSec = _timeoutSec;
            
            var objsFromAPI = SendRequest<CreateSupportBundleResult>("CreateSupportBundle", request);
            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result);
            }
        }

        #endregion

        public override void BeforeRequest(ref RpcBase request, ref string method, SFConnection connection)
        {
            // Override SFConnection.Timeout.
            // set timeout of underlying HttpClient to anticipate a different duration than normal.
            SetTimeout(new TimeSpan(0, 0, _timeoutSec + HTTP_TIMEOUT_BUFFER_SECS));
        }
    }
}