﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;

#endregion

namespace SolidFire.Node.Remove
{
    /// <summary>
    /// RemoveNodes is used to remove one or more nodes that should no longer participate in the cluster. Before removing a node,
    /// all drives it contains must first be removed with RemoveDrives method. A node cannot be removed until the RemoveDrives
    /// process has completed and all data has been migrated away from the node.
    /// 
    /// Once removed, a node registers itself as a pending node and can be added again, or shut down which removes it from the
    /// Pending Node list.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFNode", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFNode : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters
        /// <summary>
        /// List of NodeIDs for the nodes to be removed.
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "List of NodeIDs for the nodes to be removed.")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] NodeID { get; set; }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            // Assemble the parameters object
            var parameters = new Dictionary<string, object>
                {
                    {"nodes", NodeID}
                };
            var request = new RemoveNodesRequest();
            request.Nodes = NodeID;

            SendRequest<RemoveNodesResult>("RemoveNodes", request);
        }
        #endregion
    }
}