﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System.Linq;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Core.Helpers;
using SolidFire.Element.Api;

#endregion

namespace SolidFire.Node.Reset
{

    [Cmdlet(VerbsCommon.Reset, "SFNode", SupportsShouldProcess = true,
        ConfirmImpact = ConfirmImpact.High)]
    public class ResetSFNode : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters

        /// <summary>
        /// 
        /// </summary>
        [Parameter(Position = 0, Mandatory = true,
                HelpMessage =
                    "Used to specify the URL to a remote Element software image to which the node will be reset.")
        ]
        public string Build { get; set; }

        [Parameter(HelpMessage = "Used to enter specifications for running the reset operation.")]
        public string Options { get; set; }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection(endPoint: SolidFireUtilities.SFEndPoint.Node);
        }

        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var request = new ResetNodeRequest
            {
                Force = true,
                Build = Build
            };

            WriteWarning("You can only use Reset-SFNode on nodes that are not \"Active\" in a cluster.");
            WriteWarning("This command clears any customer data that is on the node.");

            WriteObject(SendRequest<ResetNodeResult>("ResetNode", request).Select(r => r.Result.Details), true);

        }

        #endregion
    }
}