﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Helpers;
using SolidFire.Core;
using SolidFire.Element.Api;
using System.Linq;
#endregion

namespace SolidFire.Node.Set
{
    /// <summary>
    /// Used to set the configuration this node uses to communicate with the cluster it is associated with.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Set, "SFClusterConfig", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class SetSFClusterConfig : SFCmdlet
    {
        #region Parameters

        [Parameter(ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "Hostname of the node")]
        public string Name { get; set; }

        [Parameter(ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "Name of the cluster")]
        public string Cluster { get; set; }

        [Parameter(ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "The management interface of the node (Bond1G or Bond10G)")]
        [ValidateSet("Bond10G", "Bond1G", IgnoreCase = true)]
        public string Mipi { get; set; }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection(endPoint: SolidFireUtilities.SFEndPoint.Node);
        }
        
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var request = new SetClusterConfigRequest();
            request.Cluster = new ClusterConfig();
            request.Cluster.Name = Name;
            request.Cluster.Cluster = Cluster;
            request.Cluster.Mipi = Mipi;

            var objsFromAPI = SendRequest<SetClusterConfigResult>("SetClusterConfig", request);

            WriteObject(objsFromAPI.Select(obj => obj.Result.Cluster), true);
            
        }
        #endregion
    }
}