#region Copyright
/*
* Copyright 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion


#region Using Directives
using System;
using System.Linq;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.StorageContainers
{
	/// <summary>
	/// Modifies an existing storage container.
	/// </summary>
	
	[Cmdlet(VerbsCommon.Set, "SFStorageContainer")]
	public class SetSFStorageContainer : SFCmdlet
	{
		#region Private Data
		private Guid _storageContainerID;
		private String _initiatorSecret;
		private String _targetSecret;
		#endregion

		#region Parameters
		[Parameter(Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "The ID of the storage container you wish to update.")]
		public Guid StorageContainerID
		{
			get
			{
				return _storageContainerID;
			}
			set
			{
				_storageContainerID = value;
			}
		}

		[Parameter(Mandatory = false, HelpMessage = "The secret for CHAP authentication for the initiator")]
		public String InitiatorSecret
		{
			get
			{
				return _initiatorSecret;
			}
			set
			{
				_initiatorSecret = value;
			}
		}

		[Parameter(Mandatory = false, HelpMessage = "The secret for CHAP authentication for the target")]
		public String TargetSecret
		{
			get
			{
				return _targetSecret;
			}
			set
			{
				_targetSecret = value;
			}
		}
		#endregion

		#region Cmdlet Overrides
		protected override void BeginProcessing()
		{
			base.BeginProcessing();
			CheckConnection(9);
		}

		protected override void ProcessRecord()
		{
			base.ProcessRecord();
			var request = new ModifyStorageContainerRequest();
			request.InitiatorSecret = _initiatorSecret;
			request.TargetSecret = _targetSecret;
			request.StorageContainerID = _storageContainerID;
			var objsFromAPI = SendRequest<ModifyStorageContainerResult>("ModifyStorageContainer", request);
			WriteObject(objsFromAPI.Select(obj => obj.Result.StorageContainer), true);
		}
		#endregion
	}
}
		