﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Volume.Get
{
    
    [Cmdlet(VerbsCommon.Get, "SFLunAssignment", DefaultParameterSetName = "VolumeAccessGroupID")]
    public class GetSFLunAssignment : SFCmdlet
    {
        #region Private Data


        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "VolumeAccessGroupID", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a volume access group ID")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64[] VolumeAccessGroupID { get; set; }

        [Parameter(Position = 0, ParameterSetName = "VolumeAccessGroup", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a volume access group")]
        [ValidateNotNullOrEmpty]
        public VolumeAccessGroup[] VolumeAccessGroup { get; set; }
        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            switch (ParameterSetName)
            {
                case "VolumeAccessGroupID":
                    ProcessByVolumeAccessGroupId();
                    break;

                case "VolumeAccessGroup":
                    ProcessByVolumeAccessGroup();
                    break;

                default:
                    throw new ArgumentException("Invalid parameter set.");
            }
        }

        private void ProcessByVolumeAccessGroup()
        {
            foreach (var volumeAccessGroup in VolumeAccessGroup)
            {
                var request = new GetVolumeAccessGroupLunAssignmentsRequest();
                request.VolumeAccessGroupID = volumeAccessGroup.VolumeAccessGroupID;

                var objsFromAPI = SendRequest<GetVolumeAccessGroupLunAssignmentsResult>("GetVolumeAccessGroupLunAssignments", request);
                foreach (var obj in objsFromAPI)
                {
                    WriteObject(obj.Result.VolumeAccessGroupLunAssignments);
                }
            }
        }

        private void ProcessByVolumeAccessGroupId()
        {
            foreach (var id in VolumeAccessGroupID)
            {
                var request = new GetVolumeAccessGroupLunAssignmentsRequest();
                request.VolumeAccessGroupID = id;
                var objsFromAPI = SendRequest<GetVolumeAccessGroupLunAssignmentsResult>("GetVolumeAccessGroupLunAssignments", request);

                foreach (var obj in objsFromAPI)
                {
                    WriteObject(obj.Result.VolumeAccessGroupLunAssignments);
                }
            }
        }

        #endregion
    }
}
