﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
using System.Management.Automation.Runspaces;
#endregion

namespace SolidFire.Volume.Invoke
{
    /// <summary>
    /// RestoreDeletedVolume marks a deleted volume as active again. This action makes the volume immediately available for iSCSI connection.
    /// </summary>
    
    [Cmdlet(VerbsLifecycle.Invoke, "SFRestoreDeletedVolume")]
    public class InvokeSFRestoreDeletedVolume : SFCmdlet
    {
        #region Private Data

        private Pipeline pipeline;

        #endregion

        #region Parameters

        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a VolumeID for the deleted volume to restore.")]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 VolumeID { get; set; }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
            pipeline = Runspace.DefaultRunspace.CreateNestedPipeline();
        }

        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var request = new RestoreDeletedVolumeRequest();
            request.VolumeID = VolumeID;
            SendRequest<RestoreDeletedVolumeResult>("RestoreDeletedVolume", request);

        }

        protected override void EndProcessing()
        {
            base.EndProcessing();
            var command = new Command("Get-SFVolume");
            command.Parameters.Add("VolumeID", VolumeID);
            if (SFConnection != null)
            {
                command.Parameters.Add("SFConnection", SFConnection);
            }
            else if (Target != null)
            {
                command.Parameters.Add("Target", Target);
            }
            pipeline.Commands.Add(command);
            WriteObject(pipeline.Invoke(), true);
            pipeline = null;
        }

        #endregion
    }
}