﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core;
using SolidFire.Element.Api;

#endregion

namespace SolidFire.Volume.Remove
{
    /// <summary>
    /// Used to remove the remote pairing between two volumes.
    /// </summary>
    
    [Cmdlet(VerbsCommon.Remove, "SFVolumePair", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class RemoveSFVolumePair : SFCmdlet
    {
        #region Private Data

        #endregion

        #region Parameters

        /// <summary>
        /// ID of the volume on which to stop the replication process.
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "ID of the volume on which to stop the replication process.")]
        public long VolumeID { get; set; }

        #endregion

        #region Cmdlet Overrides
        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
        }

        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var request = new RemoveVolumePairRequest();
            request.VolumeID = VolumeID;

            var objsFromAPI = SendRequest<RemoveVolumePairResult>("RemoveVolumePair", request);

            foreach (var obj in objsFromAPI)
            {
                WriteObject(obj.Result);
            }
        }

        #endregion
    }
}