﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives

using System;
using System.ComponentModel;
using System.Management.Automation;
using System.Management.Automation.Runspaces;
using SolidFire.Core.Validation;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Volume.Set
{
    
    [Cmdlet(VerbsCommon.Set, "SFLunAssignment", DefaultParameterSetName = "VolumeAccessGroupID", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class SetSFLunAssignment : SFCmdlet
    {
        #region Private Data

        private Pipeline _pipeline;

        private Int64 _processedID;

        #endregion

        #region Parameters

        [Parameter(Position = 0, ParameterSetName = "VolumeAccessGroupID", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a volume access group ID")]
        [ValidateNotNullOrEmpty]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 VolumeAccessGroupID { get; set; }

        [Parameter(Position = 0, ParameterSetName = "VolumeAccessGroup", Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a volume access group")]
        [ValidateNotNullOrEmpty]
        public VolumeAccessGroup VolumeAccessGroup { get; set; }

        [Parameter(Position = 1,  Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, ValueFromRemainingArguments = false, HelpMessage = "Please enter a LunAssignment")]
        [ValidateNotNullOrEmpty]
        public LunAssignment[] LunAssignment { get; set; }

        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
            _pipeline = Runspace.DefaultRunspace.CreateNestedPipeline();
        }
        protected override void ProcessRecord()
        {
            base.ProcessRecord();

            var id = VolumeAccessGroupID;

            if (ParameterSetName == "VolumeAccessGroup")
            {
                id = VolumeAccessGroup.VolumeAccessGroupID;
            }

            _processedID = id;

            var request = new ModifyVolumeAccessGroupLunAssignmentsRequest();
            request.VolumeAccessGroupID = id;
            request.LunAssignments = LunAssignment;
            
            SendRequest<ModifyVolumeAccessGroupLunAssignmentsResult>(
                "ModifyVolumeAccessGroupLunAssignments", request);

        }

        protected override void EndProcessing()
        {
            base.EndProcessing();
            var command = new Command("Get-SFLunAssignment");
            command.Parameters.Add("VolumeAccessGroupID", _processedID);
            if (SFConnection != null)
            {
                command.Parameters.Add("SFConnection", SFConnection);
            }
            else if (Target != null)
            {
                command.Parameters.Add("Target", Target);
            }
            _pipeline.Commands.Add(command);
            WriteObject(_pipeline.Invoke(), true);
            _pipeline = null;
        }

        #endregion
    }
}
