﻿#region Copyright
/*
* Copyright © 2014-2016 NetApp, Inc. All Rights Reserved.
*
* CONFIDENTIALITY NOTICE: THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
* NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
* EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
*/
#endregion

#region Using Directives
using System;
using System.Collections;
using System.ComponentModel;
using System.Management.Automation;
using SolidFire.Core.Validation;
using System.Management.Automation.Runspaces;
using SolidFire.Core;
using SolidFire.Element.Api;
#endregion

namespace SolidFire.Volume.Set
{
    /// <summary>
    ///
    /// 
    /// </summary>
    
    [Cmdlet(VerbsCommon.Set, "SFVolumeAccessGroup", SupportsShouldProcess = true, ConfirmImpact = ConfirmImpact.High)]
    public class SetSFVolumeAccessGroup : SFCmdlet
    {
        #region Private Data

        private Int64 volumeAccessGroupID;

        private Pipeline pipeline;


        #endregion

        #region Parameters
        /// <summary>
        /// The ID of the volume access group to modify.
        /// </summary>
        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ValueFromPipelineByPropertyName = true, HelpMessage = "The ID of the volume access group to modify")]
        [ValidatePattern(SolidFireValidations.Numeric)]
        public Int64 VolumeAccessGroupID
        {
            get { return volumeAccessGroupID; }
            set { volumeAccessGroupID = value; }
        }

        /// <summary>
        /// The new name for this volume access group.
        /// </summary>
        [Parameter(Position = 1, Mandatory = false, ValueFromPipeline = false, ValueFromPipelineByPropertyName = false, HelpMessage = "The new name for this volume access group")]
        [ValidatePattern(SolidFireValidations.UpperAndLowerCaseNumericAndDots)]
        public string Name { get; set; }

        /// <summary>
        /// List of Name/Value pairs to save with the VAG in JSON object format.
        /// </summary>
        [Parameter(Position = 2, Mandatory = false, ValueFromPipeline = false, ValueFromPipelineByPropertyName = false, HelpMessage = "Attributes to set")]
        public Hashtable Attributes { get; set; }

        [Parameter(Mandatory = false, ValueFromPipeline = false, ValueFromPipelineByPropertyName = false, HelpMessage = "The ID of the SolidFire Virtual Network ID to associate the volume access group with.")]
        public Int64[] VirtualNetworkID { get; set; }
        [Parameter(Mandatory = false, ValueFromPipeline = false, ValueFromPipelineByPropertyName = false, HelpMessage = "The ID of the VLAN Virtual Network Tag to associate the volume access group with.")]
        public Int64[] VirtualNetworkTags { get; set; }
        [Parameter(Mandatory = false, HelpMessage = "List of initiators to include in the volume access group. If unspecified, the access group's configured initiators will not be modified.")]
        public string[] Initiators { get; set; }
        [Parameter(Mandatory = false, HelpMessage = "List of volumes to initially include in the volume access group. If unspecified, the access group's volumes will not be modified.")]
        public Int64[] Volumes { get; set; }
        #endregion

        #region Cmdlet Overrides

        protected override void BeginProcessing()
        {
            base.BeginProcessing();
            CheckConnection();
            pipeline = Runspace.DefaultRunspace.CreateNestedPipeline();
        }

        protected override void EndProcessing()
        {
            base.EndProcessing();
            var command = new Command("Get-SFVolumeAccessGroup");
            command.Parameters.Add("VolumeAccessGroupID", volumeAccessGroupID);
            if (SFConnection != null)
            {
                command.Parameters.Add("SFConnection", SFConnection);
            }
            else if (Target != null)
            {
                command.Parameters.Add("Target", Target);
            }
            pipeline.Commands.Add(command);
            WriteObject(pipeline.Invoke(), true);
            pipeline = null;
        }

        /// <summary>
        /// 
        /// </summary>
        protected override void ProcessRecord()
        {
            base.ProcessRecord();
            var request = new ModifyVolumeAccessGroupRequest();
            request.VolumeAccessGroupID = volumeAccessGroupID;
            request.Name = !string.IsNullOrEmpty(this.Name) ? Name : null;
            request.Attributes = Attributes == null ? null : Attributes;
            request.VirtualNetworkID = VirtualNetworkID;
            request.VirtualNetworkTags = VirtualNetworkTags;
            request.Initiators = Initiators;
            request.Volumes = Volumes;
            SendRequest<ModifyVolumeAccessGroupResult>("ModifyVolumeAccessGroup", request);
        }

        #endregion
    }
}